@@ -5,8 +5,4 @@ Provides auxiliary services for working with Python type annotations, converting
 and generating a JSON schema for a complex type.
 """
 
-from .auxiliary import *
-from .core import *
-from .inspection import *
-from .schema import *
-from .serialization import *
+__version__ = "0.1.6"
