@@ -1,7 +1,8 @@
+from __future__ import annotations
+
 import dataclasses
 import sys
-import typing
-from typing import Optional, Union
+from typing import Optional
 
 try:
     from typing import Annotated
@@ -10,6 +11,8 @@ except ImportError:
 
 
 def _compact_dataclass_repr(obj) -> str:
+    "Compact dataclass representation where positional arguments are used instead of keyword arguments."
+
     arglist = ", ".join(
         repr(getattr(obj, field.name)) for field in dataclasses.fields(obj)
     )
@@ -23,7 +26,7 @@ class CompactDataClass:
         return _compact_dataclass_repr(self)
 
 
-def typeannotation(cls=None, /, *, eq=True, order=False):
+def typeannotation(cls: type = None, /, *, eq=True, order=False) -> type:
     "Returns the same class as was passed in, with dunder methods added based on the fields defined in the class."
 
     data_cls = dataclasses.dataclass(
@@ -39,6 +42,13 @@ def typeannotation(cls=None, /, *, eq=True, order=False):
     return data_cls
 
 
+@typeannotation
+class Alias:
+    "Alternative name of a property, typically used in JSON serialization."
+
+    name: str
+
+
 @typeannotation
 class Signed:
     "Signedness of an integer type."
@@ -73,6 +83,17 @@ class Precision:
         return self.significant_digits - self.decimal_digits
 
 
+@typeannotation
+class TimePrecision:
+    """
+    Precision of a timestamp or time interval.
+
+    :param decimal_digits: Number of fractional digits retained in the seconds field for a timestamp.
+    """
+
+    decimal_digits: int = 0
+
+
 @typeannotation
 class MinLength:
     "Minimum length of a string."
@@ -109,6 +130,9 @@ uint64 = Annotated[
     int, Signed(False), Storage(8), IntegerRange(0, 18446744073709551615)
 ]
 
+float32 = Annotated[float, Storage(4)]
+float64 = Annotated[float, Storage(8)]
+
 # maps globals of type Annotation[T, ...] defined in this module to their string names
 _auxiliary_types = {}
 module = sys.modules[__name__]
@@ -123,76 +147,3 @@ def get_auxiliary_format(data_type: type) -> Optional[str]:
     "Returns the JSON format string corresponding to an auxiliary type."
 
     return _auxiliary_types.get(data_type)
-
-
-def _python_type_to_str(data_type: type) -> str:
-    "Returns the string representation of a Python type without metadata."
-
-    origin = typing.get_origin(data_type)
-    if origin is not None:
-        data_type_args = typing.get_args(data_type)
-
-        if origin is dict:  # Dict[T]
-            origin_name = "Dict"
-        elif origin is list:  # List[T]
-            origin_name = "List"
-        elif origin is set:  # Set[T]
-            origin_name = "Set"
-        elif origin is Union:
-            if type(None) in data_type_args:
-                # Optional[T] is represented as Union[T, None]
-                origin_name = "Optional"
-                data_type_args = tuple(t for t in data_type_args if t is not type(None))
-            else:
-                origin_name = "Union"
-        else:
-            origin_name = origin.__name__
-
-        args = ", ".join(python_type_to_str(t) for t in data_type_args)
-        return f"{origin_name}[{args}]"
-
-    if isinstance(data_type, typing.ForwardRef):
-        fwd: typing.ForwardRef = data_type
-        return fwd.__forward_arg__
-
-    return data_type.__name__
-
-
-def python_type_to_str(data_type: type) -> str:
-    "Returns the string representation of a Python type."
-
-    if data_type is type(None):
-        return "None"
-
-    # use compact name for alias types
-    name = _auxiliary_types.get(data_type)
-    if name is not None:
-        return name
-
-    metadata = getattr(data_type, "__metadata__", None)
-    if metadata is not None:
-        # type is Annotated[T, ...]
-        arg = typing.get_args(data_type)[0]
-        s = _python_type_to_str(arg)
-        args = ", ".join(repr(m) for m in metadata)
-        return f"Annotated[{s}, {args}]"
-    else:
-        # type is a regular type
-        return _python_type_to_str(data_type)
-
-
-def python_type_to_name(data_type: type) -> str:
-    "Returns the short name of a Python type."
-
-    # use compact name for alias types
-    name = _auxiliary_types.get(data_type)
-    if name is not None:
-        return name
-
-    metadata = getattr(data_type, "__metadata__", None)
-    if metadata is not None:
-        # type is Annotated[T, ...]
-        arg = typing.get_args(data_type)[0]
-        return arg.__name__
-    else:
-        return data_type.__name__
