@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import base64
 import dataclasses
 import datetime
@@ -10,8 +12,10 @@ import typing
 import uuid
 from typing import Any, Type, TypeVar, Union
 
+from .auxiliary import Alias
 from .core import JsonType
 from .inspection import (
+    get_annotation,
     get_class_properties,
     is_dataclass_instance,
     is_named_tuple_instance,
@@ -23,14 +27,21 @@ from .inspection import (
 T = TypeVar("T")
 
 
-def python_id_to_json_field(python_id: str) -> str:
+def python_id_to_json_field(python_id: str, python_type: type = None) -> str:
     """
     Convert a Python identifier to a JSON field name.
 
     Authors may use an underscore appended at the end of a Python identifier as per PEP 8 if it clashes with a Python
     keyword: e.g. `in` would become `in_` and `from` would become `from_`. Remove these suffixes when exporting to JSON.
+
+    Authors may supply an explicit alias with the type annotation `Alias`, e.g. `Annotated[MyType, Alias("alias")]`.
     """
 
+    if python_type is not None:
+        alias = get_annotation(python_type, Alias)
+        if alias:
+            return alias.name
+
     if python_id.endswith("_"):
         id = python_id[:-1]
         if keyword.iskeyword(id):
@@ -47,7 +58,11 @@ def object_to_json(obj: Any) -> JsonType:
     """
 
     # check for well-known types
-    if isinstance(obj, (bool, int, float, str)):  # can be directly represented in JSON
+    if obj is None:
+        # can be directly represented in JSON
+        return None
+    elif isinstance(obj, (bool, int, float, str)):
+        # can be directly represented in JSON
         return obj
     elif isinstance(obj, bytes):
         return base64.b64encode(obj).decode("ascii")
@@ -83,7 +98,9 @@ def object_to_json(obj: Any) -> JsonType:
             value = getattr(obj, field.name)
             if value is None:
                 continue
-            object_dict[python_id_to_json_field(field.name)] = object_to_json(value)
+            object_dict[
+                python_id_to_json_field(field.name, field.type)
+            ] = object_to_json(value)
         return object_dict
 
     elif is_named_tuple_instance(obj):
@@ -140,7 +157,11 @@ def json_to_object(typ: Type[T], data: JsonType) -> T:
     """
 
     # check for well-known types
-    if typ is bool or typ is int or typ is float or typ is str:
+    if typ is type(None):
+        if data is not None:
+            raise TypeError(f"non-null data for null type")
+        return None
+    elif typ is bool or typ is int or typ is float or typ is str:
         return data
     elif typ is bytes:
         return base64.b64decode(data)
@@ -203,7 +224,7 @@ def json_to_object(typ: Type[T], data: JsonType) -> T:
 
     obj = object.__new__(typ)
     for property_name, property_type in get_class_properties(typ):
-        json_name = python_id_to_json_field(property_name)
+        json_name = python_id_to_json_field(property_name, property_type)
         if is_type_optional(property_type):
             if json_name in data:
                 setattr(
